@@ -323,14 +323,7 @@ class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attrib
                     for ignore_rule_id in ignore_rule_ids:
                         if ignore_rule_id not in results:
                             results[ignore_rule_id] = []
-                        value_location = self._loc(resource_values)
-                        name_location = self._loc(resource_name)
-                        results[ignore_rule_id].append(
-                            {
-                                "start": (name_location[0] + 1, name_location[1] + 1),
-                                "end": (value_location[2] + 1, value_location[3] + 1),
-                            }
-                        )
+                        results[ignore_rule_id].append(resource_name)
         return results
 
     # pylint: disable=too-many-locals
@@ -872,13 +865,13 @@ class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attrib
         # if resource condition isn't available then the resource is available
         return results
 
-    def get_object_without_nested_conditions(self, obj, path):
+    def get_object_without_nested_conditions(self, obj, path, region=None):
         """
         Get a list of object values without conditions included.
         Evaluates deep into the object removing any nested conditions as well
         """
         results = []
-        scenarios = self.get_condition_scenarios_below_path(path)
+        scenarios = self.get_condition_scenarios_below_path(path, False, region)
         if not isinstance(obj, (dict, list)):
             return results
 
@@ -978,7 +971,7 @@ class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attrib
 
         return result
 
-    def get_object_without_conditions(self, obj, property_names=None):
+    def get_object_without_conditions(self, obj, property_names=None, region=None):
         """
         Gets a list of object values without conditions included
         Input:
@@ -1018,7 +1011,7 @@ class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attrib
             o = deepcopy(obj)
         results = []
 
-        scenarios = self.get_conditions_scenarios_from_object([o])
+        scenarios = self.get_conditions_scenarios_from_object([o], region)
         if not isinstance(obj, dict):
             return results
 
@@ -1036,7 +1029,9 @@ class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attrib
 
         return results
 
-    def get_condition_scenarios_below_path(self, path, include_if_in_function=False):
+    def get_condition_scenarios_below_path(
+        self, path, include_if_in_function=False, region=None
+    ):
         """
         get Condition Scenarios from below path
         """
@@ -1055,9 +1050,9 @@ class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attrib
                         else:
                             results[condition_name] = condition_values
 
-        return list(self.conditions.build_scenarios(list(results.keys())))
+        return list(self.conditions.build_scenarios(list(results.keys()), region))
 
-    def get_conditions_scenarios_from_object(self, objs):
+    def get_conditions_scenarios_from_object(self, objs, region=None):
         """
         Get condition from objects
         """
@@ -1105,7 +1100,7 @@ class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attrib
                     else:
                         con = con.union(get_conditions_from_property(v))
 
-        return list(self.conditions.build_scenarios(list(con)))
+        return list(self.conditions.build_scenarios(list(con), region))
 
     def get_conditions_from_path(
         self,
